@@ -3,9 +3,9 @@ package MooseX::AlwaysCoerce;
 use strict;
 use warnings;
 
-use namespace::autoclean;
+use namespace::autoclean 0.12;
 use Moose ();
-use MooseX::ClassAttribute ();
+use MooseX::ClassAttribute 0.24 ();
 use Moose::Exporter;
 use Moose::Util::MetaRole;
 use Carp;
